@@ -13,7 +13,7 @@ global.endpoint = process.env.CONSUL_ENDPOINT || "127.0.0.1";
 global.port = process.env.CONSUL_PORT || 8500;
 global.secure = process.env.CONSUL_SECURE || false;
 global.token = process.env.TOKEN || null;
-global.seeder_file = null;
+global.config_file = null;
 global.config_key = "git2consul/config"
 
 /**
@@ -55,17 +55,17 @@ for (var i=2; i<process.argv.length; ++i) {
     global.token = process.argv[i+1];
   }
 
-  if(process.argv[i] === '-f' || process.argv[i] === '--seed-file') {
+  if(process.argv[i] === '-f' || process.argv[i] === '--config-file') {
     if(i+1 >= process.argv.length) {
-      logger.error("No token provided with --seed-file option");
+      logger.error("No token provided with --config-file option");
       process.exit(7);
     }
-    global.seeder_file = process.argv[i+1];
+    global.config_file = process.argv[i+1];
   }
 }
 
-if (global.seeder_file) {
-  config_seeder.set(global.config_key, global.seeder_file, function(err) {
+if (global.config_file) {
+  config_seeder.set(global.config_key, global.config_file, function(err) {
     if (err) {
       logger.error(error)
       process.exit(2)
